import { ErrorLike } from './errors';
import { IConfiguredSubject, IGeneratedSettings as ISettings } from '@workbench-stack/core';
/**
 * A settings subject is something that can have settings associated with it, such as a site ("global settings"),
 * an organization ("organization settings"), a user ("user settings"), etc.
 */
export type SettingsSubject = {
    id: number;
    settingsURL: string;
    viewerCanAdminister: boolean;
    __typename: any;
};
/**
 * A settings cascade that also supports representing subjects with no settings or whose settings triggered an
 * error.
 *
 * Callers that don't need to represent the null/error states should use {@link SettingsCascade}.
 *
 * @template S the settings type.
 */
export interface SettingsCascadeOrError<S extends ISettings = ISettings> {
    /**
     * The settings for each subject in the cascade, from lowest to highest precedence, null if there are none, or
     * an error
     *
     * @see SettingsCascade#subjects
     */
    subjects: ConfiguredSubjectOrError<S>[] | null;
    /**
     * The final settings (merged in order of precendence from the settings for each subject in the cascade), an
     * error (if any occurred while retrieving, parsing, or merging the settings), or null if there are no settings
     * from any of the subjects.
     *
     * @see SettingsCascade#final
     */
    final: S | ErrorLike | null;
}
/**
 * A subject and its settings, or null if there are no settings, or an error.
 *
 * Callers that don't need to represent the null/error states should use {@link ConfiguredSubject}.
 *
 * @template S the settings type
 */
export interface ConfiguredSubjectOrError<S extends ISettings = ISettings> extends Pick<IConfiguredSubject<S>, Exclude<keyof IConfiguredSubject<S>, 'settings'>> {
    /**
     * The subject's settings (if any), an error (if any occurred while retrieving or parsing the settings), or
     * null if there are no settings.
     */
    settings: S | ErrorLike | null;
}
